Bobby R. Bruce has uploaded this change for review. ( https://gem5-review.googlesource.com/c/public/gem5/+/33143 )

Change subject: tests: Moved realview config files
......................................................................

tests: Moved realview config files

This is part of a process of getting rid of the `tests/config`
directory, and placing these configs either where they are used,
removing them if unneeded, or moving them to `configs/example`.

These config files, in this patchset, are part of the realview tests
found in `tests/gem5/fs/linux/arm/`. They have therefore been moved
there.

Change-Id: I7706b59c58da6413f5f3dd816a1e5cd54a834a58
---
R configs/example/base_arm_config.py
M tests/configs/minor-timing-mp.py
M tests/configs/minor-timing.py
M tests/configs/o3-timing-checker.py
M tests/configs/o3-timing-mp.py
M tests/configs/o3-timing-mt.py
M tests/configs/o3-timing.py
M tests/configs/simple-atomic-dummychecker.py
M tests/configs/simple-atomic-mp.py
M tests/configs/simple-atomic.py
M tests/configs/simple-timing-mp.py
M tests/configs/simple-timing.py
M tests/configs/x86_generic.py
R tests/gem5/fs/linux/arm/configs/arm_generic.py
R tests/gem5/fs/linux/arm/configs/checkpoint.py
R tests/gem5/fs/linux/arm/configs/realview-minor-dual.py
R tests/gem5/fs/linux/arm/configs/realview-minor.py
R tests/gem5/fs/linux/arm/configs/realview-o3-checker.py
R tests/gem5/fs/linux/arm/configs/realview-o3-dual.py
R tests/gem5/fs/linux/arm/configs/realview-o3.py
R tests/gem5/fs/linux/arm/configs/realview-simple-atomic-checkpoint.py
R tests/gem5/fs/linux/arm/configs/realview-simple-atomic-dual.py
R tests/gem5/fs/linux/arm/configs/realview-simple-atomic.py
R tests/gem5/fs/linux/arm/configs/realview-simple-timing-dual-ruby.py
R tests/gem5/fs/linux/arm/configs/realview-simple-timing-dual.py
R tests/gem5/fs/linux/arm/configs/realview-simple-timing-ruby.py
R tests/gem5/fs/linux/arm/configs/realview-simple-timing.py
R tests/gem5/fs/linux/arm/configs/realview-switcheroo-atomic.py
R tests/gem5/fs/linux/arm/configs/realview-switcheroo-full.py
R tests/gem5/fs/linux/arm/configs/realview-switcheroo-noncaching-timing.py
R tests/gem5/fs/linux/arm/configs/realview-switcheroo-o3.py
R tests/gem5/fs/linux/arm/configs/realview-switcheroo-timing.py
R tests/gem5/fs/linux/arm/configs/realview64-minor-dual.py
R tests/gem5/fs/linux/arm/configs/realview64-minor.py
R tests/gem5/fs/linux/arm/configs/realview64-o3-checker.py
R tests/gem5/fs/linux/arm/configs/realview64-o3-dual.py
R tests/gem5/fs/linux/arm/configs/realview64-o3.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-atomic-checkpoint.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-atomic-dual.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-atomic.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-timing-dual-ruby.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-timing-dual.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-timing-ruby.py
R tests/gem5/fs/linux/arm/configs/realview64-simple-timing.py
R tests/gem5/fs/linux/arm/configs/realview64-switcheroo-atomic.py
R tests/gem5/fs/linux/arm/configs/realview64-switcheroo-full.py
R tests/gem5/fs/linux/arm/configs/realview64-switcheroo-o3.py
R tests/gem5/fs/linux/arm/configs/realview64-switcheroo-timing.py
R tests/gem5/fs/linux/arm/configs/switcheroo.py
M tests/gem5/fs/linux/arm/run.py
M tests/gem5/fs/linux/arm/test.py
51 files changed, 25 insertions(+), 23 deletions(-)



diff --git a/tests/configs/base_config.py b/configs/example/base_arm_config.py
similarity index 99%
rename from tests/configs/base_config.py
rename to configs/example/base_arm_config.py
index b124a13..b5bddf4 100644
--- a/tests/configs/base_config.py
+++ b/configs/example/base_arm_config.py
@@ -38,7 +38,6 @@
 import m5
 from m5.objects import *
 from m5.proxy import *
-m5.util.addToPath('../configs/')
 from common import FSConfig
 from common import Options
 from common.Caches import *
diff --git a/tests/configs/minor-timing-mp.py b/tests/configs/minor-timing-mp.py
index 4283c3f..100edab 100644
--- a/tests/configs/minor-timing-mp.py
+++ b/tests/configs/minor-timing-mp.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 nb_cores = 4
 root = BaseSESystem(mem_mode='timing', mem_class=DDR3_1600_8x8,
diff --git a/tests/configs/minor-timing.py b/tests/configs/minor-timing.py
index 6c1b517..71f6a0f 100644
--- a/tests/configs/minor-timing.py
+++ b/tests/configs/minor-timing.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 root = BaseSESystemUniprocessor(mem_mode='timing', mem_class=DDR3_1600_8x8,
                                 cpu_class=MinorCPU).create_root()
diff --git a/tests/configs/o3-timing-checker.py b/tests/configs/o3-timing-checker.py
index c82a6c8..b0d4155 100644
--- a/tests/configs/o3-timing-checker.py
+++ b/tests/configs/o3-timing-checker.py
@@ -34,7 +34,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 root = BaseSESystemUniprocessor(mem_mode='timing', mem_class=DDR3_1600_8x8,
                                 cpu_class=DerivO3CPU,
diff --git a/tests/configs/o3-timing-mp.py b/tests/configs/o3-timing-mp.py
index 5c68a60..fcdda85 100644
--- a/tests/configs/o3-timing-mp.py
+++ b/tests/configs/o3-timing-mp.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 nb_cores = 4
 root = BaseSESystem(mem_mode='timing', mem_class=DDR3_1600_8x8,
diff --git a/tests/configs/o3-timing-mt.py b/tests/configs/o3-timing-mt.py
index 5c98f33..b2a92a7 100644
--- a/tests/configs/o3-timing-mt.py
+++ b/tests/configs/o3-timing-mt.py
@@ -38,7 +38,7 @@

 from m5.objects import *
 from m5.defines import buildEnv
-from base_config import *
+from base_arm_config import *
 from arm_generic import *
 from common.cores.arm.O3_ARM_v7a import O3_ARM_v7a_3

diff --git a/tests/configs/o3-timing.py b/tests/configs/o3-timing.py
index 3788df9..d4e3d74 100644
--- a/tests/configs/o3-timing.py
+++ b/tests/configs/o3-timing.py
@@ -38,7 +38,7 @@

 from m5.objects import *
 from m5.defines import buildEnv
-from base_config import *
+from base_arm_config import *
 from arm_generic import *
 from common.cores.arm.O3_ARM_v7a import O3_ARM_v7a_3

diff --git a/tests/configs/simple-atomic-dummychecker.py b/tests/configs/simple-atomic-dummychecker.py
index 42d1cee..74b08ea 100644
--- a/tests/configs/simple-atomic-dummychecker.py
+++ b/tests/configs/simple-atomic-dummychecker.py
@@ -34,7 +34,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 root = BaseSESystemUniprocessor(mem_mode='atomic',
                                 cpu_class=AtomicSimpleCPU,
diff --git a/tests/configs/simple-atomic-mp.py b/tests/configs/simple-atomic-mp.py
index 5e9b465..2482621 100644
--- a/tests/configs/simple-atomic-mp.py
+++ b/tests/configs/simple-atomic-mp.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 nb_cores = 4
 root = BaseSESystem(mem_mode='atomic', cpu_class=AtomicSimpleCPU,
diff --git a/tests/configs/simple-atomic.py b/tests/configs/simple-atomic.py
index 3c698f5..15586e6 100644
--- a/tests/configs/simple-atomic.py
+++ b/tests/configs/simple-atomic.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 root = BaseSESystemUniprocessor(mem_mode='atomic',
                                 cpu_class=AtomicSimpleCPU).create_root()
diff --git a/tests/configs/simple-timing-mp.py b/tests/configs/simple-timing-mp.py
index 8712cb9..ae2e2e0 100644
--- a/tests/configs/simple-timing-mp.py
+++ b/tests/configs/simple-timing-mp.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 nb_cores = 4
 root = BaseSESystem(mem_mode='timing', cpu_class=TimingSimpleCPU,
diff --git a/tests/configs/simple-timing.py b/tests/configs/simple-timing.py
index d7d6171..8df12b9 100644
--- a/tests/configs/simple-timing.py
+++ b/tests/configs/simple-timing.py
@@ -37,7 +37,7 @@
 # OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

 from m5.objects import *
-from base_config import *
+from base_arm_config import *

 root = BaseSESystemUniprocessor(mem_mode='timing',
                                 cpu_class=TimingSimpleCPU).create_root()
diff --git a/tests/configs/x86_generic.py b/tests/configs/x86_generic.py
index 1ab5d3b..817bed7 100644
--- a/tests/configs/x86_generic.py
+++ b/tests/configs/x86_generic.py
@@ -41,7 +41,7 @@
 from common.Benchmarks import SysConfig
 from common import FSConfig, SysPaths
 from common.Caches import *
-from base_config import *
+from base_arm_config import *

 class LinuxX86SystemBuilder(object):
     """Mix-in that implements create_system.
diff --git a/tests/configs/arm_generic.py b/tests/gem5/fs/linux/arm/configs/arm_generic.py
similarity index 99%
rename from tests/configs/arm_generic.py
rename to tests/gem5/fs/linux/arm/configs/arm_generic.py
index dc87e68..c9c2d49 100644
--- a/tests/configs/arm_generic.py
+++ b/tests/gem5/fs/linux/arm/configs/arm_generic.py
@@ -40,7 +40,7 @@
 m5.util.addToPath('../configs/')
 from common import FSConfig
 from common.Caches import *
-from base_config import *
+from base_arm_config import *
 from common.cores.arm.O3_ARM_v7a import *
 from common.Benchmarks import SysConfig

diff --git a/tests/gem5/fs/linux/arm/run.py b/tests/gem5/fs/linux/arm/run.py
index 15bfe21..7b29bce 100644
--- a/tests/gem5/fs/linux/arm/run.py
+++ b/tests/gem5/fs/linux/arm/run.py
@@ -57,12 +57,13 @@

 config = sys.argv[1]
 os.environ['M5_PATH'] = sys.argv[2]
+gem5_root = sys.argv[3]

 # path setup
-gem5_root = joinpath(os.path.dirname(__file__), '..', '..', '..', '..', '..')
+cur_dir = os.path.dirname(__file__)
 sys.path.append(joinpath(gem5_root, 'configs'))
-tests_root = joinpath(gem5_root, 'tests')
-sys.path.append(joinpath(tests_root, 'configs'))
+sys.path.append(joinpath(gem5_root, 'configs', 'example'))
+sys.path.append(joinpath(cur_dir, 'configs'))

 exec(compile(open(config).read(), config, 'exec'))

diff --git a/tests/gem5/fs/linux/arm/test.py b/tests/gem5/fs/linux/arm/test.py
index 3dabda8..1da2207 100644
--- a/tests/gem5/fs/linux/arm/test.py
+++ b/tests/gem5/fs/linux/arm/test.py
@@ -90,8 +90,9 @@

 for name in arm_fs_quick_tests:
     args = [
-        joinpath(config.base_dir, 'tests', 'configs', name + '.py'),
-        path
+        joinpath(filepath, 'configs', name + '.py'),
+        path,
+        config.base_dir
     ]
     gem5_verify_config(
         name=name,
@@ -105,8 +106,9 @@

 for name in arm_fs_long_tests:
     args = [
-        joinpath(config.base_dir, 'tests', 'configs', name + '.py'),
-        path
+        joinpath(filepath, 'configs', name + '.py'),
+        path,
+        config.base_dir
     ]
     gem5_verify_config(
         name=name,

diff --git a/tests/configs/checkpoint.py b/tests/gem5/fs/linux/arm/configs/checkpoint.py
similarity index 100%
rename from tests/configs/checkpoint.py
rename to tests/gem5/fs/linux/arm/configs/checkpoint.py
diff --git a/tests/configs/realview-minor-dual.py b/tests/gem5/fs/linux/arm/configs/realview-minor-dual.py
similarity index 100%
rename from tests/configs/realview-minor-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview-minor-dual.py
diff --git a/tests/configs/realview-minor.py b/tests/gem5/fs/linux/arm/configs/realview-minor.py
similarity index 100%
rename from tests/configs/realview-minor.py
rename to tests/gem5/fs/linux/arm/configs/realview-minor.py
diff --git a/tests/configs/realview-o3-checker.py b/tests/gem5/fs/linux/arm/configs/realview-o3-checker.py
similarity index 100%
rename from tests/configs/realview-o3-checker.py
rename to tests/gem5/fs/linux/arm/configs/realview-o3-checker.py
diff --git a/tests/configs/realview-o3-dual.py b/tests/gem5/fs/linux/arm/configs/realview-o3-dual.py
similarity index 100%
rename from tests/configs/realview-o3-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview-o3-dual.py
diff --git a/tests/configs/realview-o3.py b/tests/gem5/fs/linux/arm/configs/realview-o3.py
similarity index 100%
rename from tests/configs/realview-o3.py
rename to tests/gem5/fs/linux/arm/configs/realview-o3.py
diff --git a/tests/configs/realview-simple-atomic-checkpoint.py b/tests/gem5/fs/linux/arm/configs/realview-simple-atomic-checkpoint.py
similarity index 100%
rename from tests/configs/realview-simple-atomic-checkpoint.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-atomic-checkpoint.py diff --git a/tests/configs/realview-simple-atomic-dual.py b/tests/gem5/fs/linux/arm/configs/realview-simple-atomic-dual.py
similarity index 100%
rename from tests/configs/realview-simple-atomic-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-atomic-dual.py
diff --git a/tests/configs/realview-simple-atomic.py b/tests/gem5/fs/linux/arm/configs/realview-simple-atomic.py
similarity index 100%
rename from tests/configs/realview-simple-atomic.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-atomic.py
diff --git a/tests/configs/realview-simple-timing-dual-ruby.py b/tests/gem5/fs/linux/arm/configs/realview-simple-timing-dual-ruby.py
similarity index 100%
rename from tests/configs/realview-simple-timing-dual-ruby.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-timing-dual-ruby.py diff --git a/tests/configs/realview-simple-timing-dual.py b/tests/gem5/fs/linux/arm/configs/realview-simple-timing-dual.py
similarity index 100%
rename from tests/configs/realview-simple-timing-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-timing-dual.py
diff --git a/tests/configs/realview-simple-timing-ruby.py b/tests/gem5/fs/linux/arm/configs/realview-simple-timing-ruby.py
similarity index 100%
rename from tests/configs/realview-simple-timing-ruby.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-timing-ruby.py
diff --git a/tests/configs/realview-simple-timing.py b/tests/gem5/fs/linux/arm/configs/realview-simple-timing.py
similarity index 100%
rename from tests/configs/realview-simple-timing.py
rename to tests/gem5/fs/linux/arm/configs/realview-simple-timing.py
diff --git a/tests/configs/realview-switcheroo-atomic.py b/tests/gem5/fs/linux/arm/configs/realview-switcheroo-atomic.py
similarity index 100%
rename from tests/configs/realview-switcheroo-atomic.py
rename to tests/gem5/fs/linux/arm/configs/realview-switcheroo-atomic.py
diff --git a/tests/configs/realview-switcheroo-full.py b/tests/gem5/fs/linux/arm/configs/realview-switcheroo-full.py
similarity index 100%
rename from tests/configs/realview-switcheroo-full.py
rename to tests/gem5/fs/linux/arm/configs/realview-switcheroo-full.py
diff --git a/tests/configs/realview-switcheroo-noncaching-timing.py b/tests/gem5/fs/linux/arm/configs/realview-switcheroo-noncaching-timing.py
similarity index 100%
rename from tests/configs/realview-switcheroo-noncaching-timing.py
rename to tests/gem5/fs/linux/arm/configs/realview-switcheroo-noncaching-timing.py diff --git a/tests/configs/realview-switcheroo-o3.py b/tests/gem5/fs/linux/arm/configs/realview-switcheroo-o3.py
similarity index 100%
rename from tests/configs/realview-switcheroo-o3.py
rename to tests/gem5/fs/linux/arm/configs/realview-switcheroo-o3.py
diff --git a/tests/configs/realview-switcheroo-timing.py b/tests/gem5/fs/linux/arm/configs/realview-switcheroo-timing.py
similarity index 100%
rename from tests/configs/realview-switcheroo-timing.py
rename to tests/gem5/fs/linux/arm/configs/realview-switcheroo-timing.py
diff --git a/tests/configs/realview64-minor-dual.py b/tests/gem5/fs/linux/arm/configs/realview64-minor-dual.py
similarity index 100%
rename from tests/configs/realview64-minor-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview64-minor-dual.py
diff --git a/tests/configs/realview64-minor.py b/tests/gem5/fs/linux/arm/configs/realview64-minor.py
similarity index 100%
rename from tests/configs/realview64-minor.py
rename to tests/gem5/fs/linux/arm/configs/realview64-minor.py
diff --git a/tests/configs/realview64-o3-checker.py b/tests/gem5/fs/linux/arm/configs/realview64-o3-checker.py
similarity index 100%
rename from tests/configs/realview64-o3-checker.py
rename to tests/gem5/fs/linux/arm/configs/realview64-o3-checker.py
diff --git a/tests/configs/realview64-o3-dual.py b/tests/gem5/fs/linux/arm/configs/realview64-o3-dual.py
similarity index 100%
rename from tests/configs/realview64-o3-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview64-o3-dual.py
diff --git a/tests/configs/realview64-o3.py b/tests/gem5/fs/linux/arm/configs/realview64-o3.py
similarity index 100%
rename from tests/configs/realview64-o3.py
rename to tests/gem5/fs/linux/arm/configs/realview64-o3.py
diff --git a/tests/configs/realview64-simple-atomic-checkpoint.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-atomic-checkpoint.py
similarity index 100%
rename from tests/configs/realview64-simple-atomic-checkpoint.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-atomic-checkpoint.py diff --git a/tests/configs/realview64-simple-atomic-dual.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-atomic-dual.py
similarity index 100%
rename from tests/configs/realview64-simple-atomic-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-atomic-dual.py
diff --git a/tests/configs/realview64-simple-atomic.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-atomic.py
similarity index 100%
rename from tests/configs/realview64-simple-atomic.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-atomic.py
diff --git a/tests/configs/realview64-simple-timing-dual-ruby.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-timing-dual-ruby.py
similarity index 100%
rename from tests/configs/realview64-simple-timing-dual-ruby.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-timing-dual-ruby.py diff --git a/tests/configs/realview64-simple-timing-dual.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-timing-dual.py
similarity index 100%
rename from tests/configs/realview64-simple-timing-dual.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-timing-dual.py
diff --git a/tests/configs/realview64-simple-timing-ruby.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-timing-ruby.py
similarity index 100%
rename from tests/configs/realview64-simple-timing-ruby.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-timing-ruby.py
diff --git a/tests/configs/realview64-simple-timing.py b/tests/gem5/fs/linux/arm/configs/realview64-simple-timing.py
similarity index 100%
rename from tests/configs/realview64-simple-timing.py
rename to tests/gem5/fs/linux/arm/configs/realview64-simple-timing.py
diff --git a/tests/configs/realview64-switcheroo-atomic.py b/tests/gem5/fs/linux/arm/configs/realview64-switcheroo-atomic.py
similarity index 100%
rename from tests/configs/realview64-switcheroo-atomic.py
rename to tests/gem5/fs/linux/arm/configs/realview64-switcheroo-atomic.py
diff --git a/tests/configs/realview64-switcheroo-full.py b/tests/gem5/fs/linux/arm/configs/realview64-switcheroo-full.py
similarity index 100%
rename from tests/configs/realview64-switcheroo-full.py
rename to tests/gem5/fs/linux/arm/configs/realview64-switcheroo-full.py
diff --git a/tests/configs/realview64-switcheroo-o3.py b/tests/gem5/fs/linux/arm/configs/realview64-switcheroo-o3.py
similarity index 100%
rename from tests/configs/realview64-switcheroo-o3.py
rename to tests/gem5/fs/linux/arm/configs/realview64-switcheroo-o3.py
diff --git a/tests/configs/realview64-switcheroo-timing.py b/tests/gem5/fs/linux/arm/configs/realview64-switcheroo-timing.py
similarity index 100%
rename from tests/configs/realview64-switcheroo-timing.py
rename to tests/gem5/fs/linux/arm/configs/realview64-switcheroo-timing.py
diff --git a/tests/configs/switcheroo.py b/tests/gem5/fs/linux/arm/configs/switcheroo.py
similarity index 97%
rename from tests/configs/switcheroo.py
rename to tests/gem5/fs/linux/arm/configs/switcheroo.py
index cb47f90..12ca230 100644
--- a/tests/configs/switcheroo.py
+++ b/tests/gem5/fs/linux/arm/configs/switcheroo.py
@@ -47,7 +47,7 @@
     The sequential CPU switches between all CPUs in a system in
     order. The CPUs in the system must have been prepared for
     switching, which in practice means that only one CPU is switched
     in. base_config.BaseFSSwitcheroo can be used to create such a
     system.
     """
     def __init__(self, cpus):
@@ -78,7 +78,7 @@
     has been prepared for CPU switching. Such systems should have
     multiple CPUs when they are instantiated, but only one should be
     switched in. Such configurations can be created using the
-    base_config.BaseFSSwitcheroo class.
+    base_arm_config.BaseFSSwitcheroo class.

     A CPU switcher object is used to control switching. The default
     switcher sequentially switches between all CPUs in a system,
@@ -47,7 +47,7 @@
     order. The CPUs in the system must have been prepared for
     switching, which in practice means that only one CPU is switched
-    in. base_config.BaseFSSwitcheroo can be used to create such a
+    in. base_arm_config.BaseFSSwitcheroo can be used to create such a
     system.
     """
--
To view, visit https://gem5-review.googlesource.com/c/public/gem5/+/33143
To unsubscribe, or for help writing mail filters, visit https://gem5-review.googlesource.com/settings

Gerrit-Project: public/gem5
Gerrit-Branch: develop
Gerrit-Change-Id: I7706b59c58da6413f5f3dd816a1e5cd54a834a58
Gerrit-Change-Number: 33143
Gerrit-PatchSet: 1
Gerrit-Owner: Bobby R. Bruce <bbr...@ucdavis.edu>
Gerrit-MessageType: newchange
_______________________________________________
gem5-dev mailing list -- gem5-dev@gem5.org
To unsubscribe send an email to gem5-dev-le...@gem5.org
%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s

Reply via email to